==> lumina-1.1.0.tar.gz: lumina-1.1.0/src-qt5/core/lumina-info/i18n/lumina-info_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Lumina Skrivebords Information</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Skrivebords Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation type="unfinished">OS Build:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Qt Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Se Information</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Anerkendelser</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Projekt ledelse:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Bidragsydere:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsorer:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Åben i en web browser&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
</TS>

==> lumina-1.2.0.tar.gz: lumina-1.2.0/src-qt5/core/lumina-info/i18n/lumina-info_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainUI</name>
    <message>
        <location filename="../MainUI.ui" line="14"/>
        <source>Lumina Desktop Information</source>
        <translation>Lumina Skrivebords Information</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="60"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="89"/>
        <source>Source Repository</source>
        <translation>Kildekodearkiv</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="124"/>
        <source>Lumina Website</source>
        <translation>Hjemmeside for Lumina</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="152"/>
        <source>Bug Reports</source>
        <translation>Fejlrapporter</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="179"/>
        <source>Desktop Version:</source>
        <translation>Skrivebords Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="202"/>
        <source>OS Build:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="218"/>
        <source>Qt Version:</source>
        <translation>Qt Version:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="276"/>
        <source>Ask the Community</source>
        <translation>Spørg fællesskabet</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="233"/>
        <source>View Information</source>
        <translation>Se Information</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="298"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="315"/>
        <source>Acknowledgements</source>
        <translation>Anerkendelser</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="333"/>
        <source>Project Lead:</source>
        <translation>Projekt ledelse:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="340"/>
        <source>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt;Ken Moore&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/beanpole135&quot;&gt; Ken Moore&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="353"/>
        <source>Contributors:</source>
        <translation>Bidragsydere:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="366"/>
        <source>Sponsors:</source>
        <translation>Sponsorer:</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="428"/>
        <source>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Open in web browser&lt;a&gt;</source>
        <translation>&lt;a href=&quot;https://github.com/pcbsd/lumina/graphs/contributors&quot;&gt;Åben i en web browser&lt;a&gt;</translation>
    </message>
    <message>
        <location filename="../MainUI.ui" line="454"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
</TS>
